#include <iostream>
#include <vector>
#include <queue>
#include <iomanip>

bool canEat(const std::vector<int64_t> &q, const std::vector<int> &f, double amt)
{
    int n = q.size();
    struct Food
    {
        double value;
        int expiry;
        bool operator<(const Food &other) const
        {
            return expiry > other.expiry;
        }
    };
    std::priority_queue<Food> pq;
    for(int i=0; i<n; i++)
    {
        while(!pq.empty() && pq.top().expiry < i)
            pq.pop();
        pq.push({double(q[i]), f[i]});
        double needed = amt;
        while(needed > 0)
        {
            if(pq.empty())
                return false;
            auto next = pq.top();
            pq.pop();
            if(needed >= next.value)
                needed -= next.value;
            else
            {
                next.value -= needed;
                needed = 0;
                pq.push(next);
            }
        }
    }
    return true;
}

int main()
{
    int n, k;
    std::cin >> n >> k;
    std::vector<int64_t> q(n);
    std::vector<int> f(n);
    
    for(int i=0; i<n; i++)
    {
        std::cin >> q[i] >> f[i];
        f[i]--;
    }
    
    double lo = 1e-10;
    double hi = 1.0;
    if(!canEat(q, f, lo))
    {
        std::cout << -1 << std::endl;
    }
    else
    {
        while(canEat(q, f, hi))
            hi *= 2.0;
        while(hi - lo > 1e-10 && (hi - lo)/lo > 1e-10)
        {
            double mid = lo + (hi-lo)/2.0;
            if(canEat(q, f, mid))
            {
                lo = mid;
            }
            else
            {
                hi = mid;
            }
        }
        std::cout << std::setprecision(30) << lo/double(k) << std::endl;
    }
}
